#include "stdio.h"
#include "stdlib.h"
#include "string.h"

#if defined NEXT486
int kgetenv(char *env,  char *name){
#elif defined MACOSX
int KGETENV(char *env,  char *name){
#elif defined PCLinux
int KGETENV(char *env,  char *name){ 
#elif defined IBMAIX
int kgetenv(char *env,  char *name){
#else
int kgetenv_(char *env,  char *name){
#endif
/*    env: input.  Environmental string to be examined.
*                 must have NULL at the end.
*     name: output. Environmental variable's value is put
*                   must have enough length (NULL is not put)
*     function value: length of the name.
*     If env is not defnied.  0 is returned.
*  The fortran routine must reset the string like
*     integer leng
*     character*1  NULL 
*     character*128 path 
*     NULL = char(0)
*     leng = kgetenv("COSMOSTOP"//NULL, path)
*     path = path(1:leng)
*/
  char *envloc;
/*  printf("%s is input\n", env); */
  if((envloc=getenv(env)) == NULL )  {
/*    printf("not found\n"); */
    return 0;
  }
  else {
/*    printf("%s\n", envloc); */
    strcpy(name, envloc);
    return  strlen(envloc);
  }
}


